/* $Workfile: OtxToneD.h $   $Revision: 18 $    $Modtime: 11/10/00 12:06p $  */
#ifndef OTX_TONE_DEF_H
#define OTX_TONE_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxToneD

  Copyright (C) 1998, 1999 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxToneD | Constants, Macros, and Types for the HDLC Functions

  @contents2
  OtxToneD.h |

  @index enum type struct | OtxToneD

  @contents2
  OTX Tone Logical Data Filter Device Macros, Constants, and Types |

  @head3 OtxToneXXX Macro, Constant, and Type Reference |

  @index enum type struct | OtxToneD

*******************************************************************************/

#include "OtxType.h"
#include "OtxErr.h"

#ifdef __cplusplus
  extern "C" {
#endif

/*---------------------------------------------------------------------------*\
  @enum
    FSK Detector Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxFskDetectorResultCodesE {
  OTX_FSK_DETECTOR_RES_END                  = OTX_RES_END +  1
};
typedef enum OtxFskDetectorResultCodesE OtxFskDetectorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    FSK Detector Event Codes
\*---------------------------------------------------------------------------*/
enum OtxFskDetectorEventCodesE {
  OTX_FSK_DETECTOR_EC_ALERT                = 0x00,
  OTX_FSK_DETECTOR_EC_COMPLETE             = 0x01,
  OTX_FSK_DETECTOR_EC_TIMEOUT              = 0x02,
  OTX_FSK_DETECTOR_EC_BYTE                 = 0x03,

  OTX_FSK_DETECTOR_END_OF_EVENT_CODES
};
typedef enum OtxFskDetectorEventCodesE OtxFskDetectorEventCodesE;



/*---------------------------------------------------------------------------*\
  @enum
    DTMF Dialer Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDialerResultCodesE {
  OTX_DTMF_DIALER_RES_INVALID_DTMF_VALUE   = OTX_RES_END +  0 ,  // @emem Invalid DTMF value        
  OTX_DTMF_DIALER_RES_BUSY                 = OTX_RES_END +  1 ,  // @emem DTMF Dialer is busy
  OTX_DTMF_DIALER_RES_END                  = OTX_RES_END +  2
};
typedef enum OtxDtmfDialerResultCodesE OtxDtmfDialerResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    DTMF Dialer Event Codes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDialerEventCodesE {
  OTX_DTMF_DIALER_EC_COMPLETE            = 0x00,
    
  OTX_DTMF_DIALER_END_OF_EVENT_CODES
};
typedef enum OtxDtmfDialerEventCodesE OtxDtmfDialerEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    Const Val Generator Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxConstValGeneratorResultCodesE {
  OTX_CONST_VAL_GENERATOR_RES_END     = OTX_RES_END +  0
};
typedef enum OtxConstValGeneratorResultCodesE OtxConstValGeneratorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Const Val Generator Event Codes
\*---------------------------------------------------------------------------*/
enum OtxConstValGeneratorEventCodesE {
    
  OTX_CONST_VAL_GENERATOR_END_OF_EVENT_CODES
};
typedef enum OtxConstValGeneratorEventCodesE OtxConstValGeneratorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    Val Sampler Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxValSamplerResultCodesE {
  OTX_VAL_SAMPLER_RES_END     = OTX_RES_END +  0
};
typedef enum OtxValSamplerResultCodesE OtxValSamplerResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Val Sampler Event Codes
\*---------------------------------------------------------------------------*/
enum OtxValSamplerEventCodesE {
    
  OTX_VAL_SAMPLER_END_OF_EVENT_CODES
};
typedef enum OtxValSamplerEventCodesE OtxValSamplerEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    Silence Detector Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxSilenceDetectorResultCodesE {
  OTX_SILENCE_DETECTOR_RES_END     = OTX_RES_END +  0
};
typedef enum OtxSilenceDetectorResultCodesE OtxSilenceDetectorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Silence Detector Event Codes
\*---------------------------------------------------------------------------*/
enum OtxSilenceDetectorEventCodesE {
    
  OTX_SILENCE_DETECTOR_END_OF_EVENT_CODES
};
typedef enum OtxSilenceDetectorEventCodesE OtxSilenceDetectorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    SineWave Generator Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxSineWaveGeneratorResultCodesE {
  OTX_SINEWAVE_GENERATOR_RES_END     = OTX_RES_END +  0
};
typedef enum OtxSineWaveGeneratorResultCodesE OtxSineWaveGeneratorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    SineWave Generator Event Codes
\*---------------------------------------------------------------------------*/
enum OtxSineWaveGeneratorEventCodesE {
    
  OTX_SINEWAVE_GENERATOR_END_OF_EVENT_CODES
};
typedef enum OtxSineWaveGeneratorEventCodesE OtxSineWaveGeneratorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    DTMF Detector Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDetectorResultCodesE {
  OTX_DTMF_DETECTOR_RES_NO_TONE         = OTX_RES_END +  0 ,  // @emem No DTMF tone presently detected        
  OTX_DTMF_DETECTOR_RES_TONE            = OTX_RES_END +  1 ,  // @emem DTMF tone is presently detected        
  OTX_DTMF_DETECTOR_RES_END             = OTX_RES_END +  2
};
typedef enum OtxDtmfDetectorResultCodesE OtxDtmfDetectorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    DTMF Detector Event Codes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDetectorEventCodesE {
  OTX_DTMF_DETECTOR_EC_DIGIT               = 0x00,  // @emem DTMF tone detected        
  OTX_DTMF_DETECTOR_EC_PAUSE               = 0x01,  // @emem Pause detected        
    
  OTX_DTMF_DETECTOR_END_OF_EVENT_CODES
};
typedef enum OtxDtmfDetectorEventCodesE OtxDtmfDetectorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    Effects Generator Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxEffectsGeneratorResultCodesE {
  OTX_EFFECTS_GENERATOR_RES_END                  = OTX_RES_END +  1
};
typedef enum OtxEffectsGeneratorResultCodesE OtxEffectsGeneratorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Effects Generator Event Codes
\*---------------------------------------------------------------------------*/
enum OtxEffectsGeneratorEventCodesE {
  // None 
  OTX_EFFECTS_GENERATOR_END_OF_EVENT_CODES
};
typedef enum OtxEffectsGeneratorEventCodesE OtxEffectsGeneratorEventCodesE;



// @enum Type of tone effect to be generated
enum OtxToneEffectE {
  OTX_TONE_SINEWAVE      = 0,  // @emem 1kHz sinusoidal wave
  OTX_TONE_SAWTOOTH      = 1,  // @emem Ramp wave
  OTX_TONE_SWEEPING_SINE = 2,  // @emem Variable frequency sinusoidal wave
  OTX_TONE_NOISE         = 3,  // @emem Random noise
  OTX_TONE_BYTE_VARIABLE = 4   // @emem Sequential bytes: 0, 1, 2, ..., 255, 0, 1, ...
};

typedef enum OtxToneEffectE OtxToneEffectE;


// @enum Type of Dual Frequency tone 
enum OtxMfToneE {
  OTX_TONE_MF_UNKNOWN     = 0,  // @emem Invalid value 
  OTX_TONE_MF_DTMF        = 1,  // @emem DTMF
  OTX_TONE_MF_R1          = 2,  // @emem CCITT R1 MF tones
  OTX_TONE_MF_R2_FORWARD  = 3,  // @emem CCITT R2 MF Forward tones
  OTX_TONE_MF_R2_BACKWARD = 4,  // @emem CCITT R2 MF Backward tones
};

typedef enum OtxMfToneE OtxMfToneE;


// @enum Gain of generated tones
enum OtxToneGainE {
  OTX_TONE_GAIN_0DB           = 0,  // @emem Full Gain
  OTX_TONE_GAIN_DG_MINUS_3DB  = 1,  // @emem -3dB Gain
  OTX_TONE_GAIN_DG_MINUS_6DB  = 2,  // @emem -6dB Gain
  OTX_TONE_GAIN_DG_MINUS_9DB  = 3,  // @emem -9dB Gain
  OTX_TONE_GAIN_DG_MINUS_12DB = 4,  // @emem -12dB Gain
  OTX_TONE_GAIN_DG_MINUS_15DB = 5   // @emem -15dB Gain
};

typedef enum OtxToneGainE OtxToneGainE;


/*******************************************************************************
  @struct
    Characteristics of a sinewave tone component. Tones containing multiple 
    frequency component can be generated by using an array of 
    this struct (see <f OtxToneSineWaveGeneratorInit>).
  @xref
   <f OtxToneSineWaveGeneratorInit>
*******************************************************************************/
struct OtxToneSineWaveDataS {
  OTX_FP64  nFrequency;    // @field Frequency of sinewave component
  OTX_FP64  nAttenuation;  // @field Attenuation of sinewave amplitude (in dB). E.g. 0dB is maximum amplitude, -3dB is 50% of maximum amplitude, -9dB is 25% of maximum amplitude.
  OTX_FP64  nPhase;        // @field Phase (in degrees) in relation to other sinewave tone components.
};

typedef struct OtxToneSineWaveDataS OtxToneSineWaveDataS;



#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998, 1999


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OTX_TONE_DEF_H
